
	.for-1-from-1-to-5 {
		content: "1";
	}
	.for-2-from-1-to-5 {
		content: "2";
	}
	.for-3-from-1-to-5 {
		content: "3";
	}
	.for-4-from-1-to-5 {
		content: "4";
	}
	.for-5-from-1-to-5 {
		content: "5";
	}

.for-1-from-1-to-5-by-2 {
		content: "1";
	}

.for-3-from-1-to-5-by-2 {
		content: "3";
	}

.for-5-from-1-to-5-by-2 {
		content: "5";
	}

.for-6-from-6-to-1-by-2 {
		content: "6";
	}

.for-4-from-6-to-1-by-2 {
		content: "4";
	}

.for-2-from-6-to-1-by-2 {
		content: "2";
	}

.each-foo-in(foo,bar,baz) {
		content: foo;
	}

.each-bar-in(foo,bar,baz) {
		content: bar;
	}

.each-baz-in(foo,bar,baz) {
		content: baz;
	}
